Struct hashbrown::hash_map::VacantEntryRef [−][src]
pub struct VacantEntryRef<'a, 'b, K, Q: ?Sized, V, S, A: Allocator + Clone = Global> { /* fields omitted */ }Expand description
A view into a vacant entry in a HashMap.
It is part of the EntryRef enum.
Implementations
Gets a reference to the key that would be used when inserting a value
through the VacantEntryRef.
Examples
use hashbrown::HashMap;
let mut map: HashMap<String, u32> = HashMap::new();
let key: &str = "poneyland";
assert_eq!(map.entry_ref(key).key(), "poneyland");Take ownership of the key.
Examples
use hashbrown::HashMap;
use hashbrown::hash_map::EntryRef;
let mut map: HashMap<String, u32> = HashMap::new();
let key: &str = "poneyland";
if let EntryRef::Vacant(v) = map.entry_ref(key) {
v.into_key();
}Sets the value of the entry with the VacantEntryRef’s key, and returns a mutable reference to it.
Examples
use hashbrown::HashMap;
use hashbrown::hash_map::EntryRef;
let mut map: HashMap<String, u32> = HashMap::new();
let key: &str = "poneyland";
if let EntryRef::Vacant(o) = map.entry_ref(key) {
o.insert(37);
}
assert_eq!(map["poneyland"], 37);